@@ -1,103 +1,5 @@
 var NAVTREEINDEX1 =
 {
-"classcl_1_1_enqueue_args.html#ab0805b653902b83b4126b097efcd06ee":[5,0,0,9,4],
-"classcl_1_1_enqueue_args.html#ab5379abd9903e0e82608ec82062406cc":[5,0,0,9,7],
-"classcl_1_1_enqueue_args.html#abc905f41d44e078a6920f5ff2d4429d6":[5,0,0,9,14],
-"classcl_1_1_enqueue_args.html#ad093a35e973b7747f90608e6121d5378":[5,0,0,9,17],
-"classcl_1_1_event.html":[5,0,0,10],
-"classcl_1_1_event.html#a3b035b8ff20d92d0b42f2f0dc8657621":[5,0,0,10,1],
-"classcl_1_1_event.html#a3f5ef317602809c4a99d6f244f758b5f":[5,0,0,10,5],
-"classcl_1_1_event.html#a4730c3b113e65efcf88aea0c9da13f52":[5,0,0,10,7],
-"classcl_1_1_event.html#a4ad1d3040fcb24188f1ac2cd73591252":[5,0,0,10,2],
-"classcl_1_1_event.html#a51f83064c2024df649667071e81fb847":[5,0,0,10,8],
-"classcl_1_1_event.html#a90e01689f7b394fc003d66c48a7f6f95":[5,0,0,10,0],
-"classcl_1_1_event.html#aa3b9f7abf39de587ee78d0b47699d5f6":[5,0,0,10,6],
-"classcl_1_1_event.html#ab76c11fecb0af5a0972903ee0f644193":[5,0,0,10,4],
-"classcl_1_1_event.html#ad3a362e550fbfa5f18e679357f1cdba8":[5,0,0,10,3],
-"classcl_1_1_image.html":[5,0,0,11],
-"classcl_1_1_image.html#a263dda8ec8a4a43e98a2dadde1b2ea31":[5,0,0,11,2],
-"classcl_1_1_image.html#a4f43cba68be8360c92efb9fac590c51d":[5,0,0,11,8],
-"classcl_1_1_image.html#a644c4f0a68b5fbb716b0157f34d903b9":[5,0,0,11,1],
-"classcl_1_1_image.html#a6c19e6b799c523fe5229a7a8f3da7431":[5,0,0,11,5],
-"classcl_1_1_image.html#a7bf98f36e2e0bd8627377cfdfc260259":[5,0,0,11,4],
-"classcl_1_1_image.html#a971175a1a2d7ae9afcbaf591b3271dcc":[5,0,0,11,7],
-"classcl_1_1_image.html#ad9a2f4b6a5ccbb7056613946bc6ee0b7":[5,0,0,11,0],
-"classcl_1_1_image.html#af47b59a0b6626ba0dd855f826f31ad9b":[5,0,0,11,3],
-"classcl_1_1_image.html#af9fda827ebfbbe8b92a5cefc5225cd69":[5,0,0,11,6],
-"classcl_1_1_image1_d.html":[5,0,0,12],
-"classcl_1_1_image1_d.html#a0d7c48026af3f726ce861716b6dbe817":[5,0,0,12,1],
-"classcl_1_1_image1_d.html#a217618087dfc7d2ab13475eca82dc13f":[5,0,0,12,5],
-"classcl_1_1_image1_d.html#a7c8b730eba37624cb6d3af30f8a1c276":[5,0,0,12,2],
-"classcl_1_1_image1_d.html#a818cbf2c71af2948f199cc4ab5d39de5":[5,0,0,12,3],
-"classcl_1_1_image1_d.html#a9bf902e7607fdfd6dacf145cae2f31e9":[5,0,0,12,0],
-"classcl_1_1_image1_d.html#aa5f07570723f701aa4fa0d8e76473db0":[5,0,0,12,7],
-"classcl_1_1_image1_d.html#ab74ea8b65b39b808cfdec016973d2770":[5,0,0,12,4],
-"classcl_1_1_image1_d.html#af584fdac9204743b4b549e85ae906c21":[5,0,0,12,6],
-"classcl_1_1_image1_d_array.html":[5,0,0,13],
-"classcl_1_1_image1_d_array.html#a36f96dc737c5e69505b6c1b4c3b6e10b":[5,0,0,13,3],
-"classcl_1_1_image1_d_array.html#a5392bebeab2ce9ae4da971c5e8f8a895":[5,0,0,13,4],
-"classcl_1_1_image1_d_array.html#a57835d50a6cfa10fa955e050036cd1e3":[5,0,0,13,1],
-"classcl_1_1_image1_d_array.html#a65b99c003dc49b5818be68c74067ecf1":[5,0,0,13,0],
-"classcl_1_1_image1_d_array.html#a8473fe05ecbc506209ad00297dd6f5c0":[5,0,0,13,7],
-"classcl_1_1_image1_d_array.html#aa291ed7bcc360d811bb5db813964efe6":[5,0,0,13,6],
-"classcl_1_1_image1_d_array.html#ad7c2cb06225fa849d0dd7069d4ec799b":[5,0,0,13,5],
-"classcl_1_1_image1_d_array.html#ae8738615a72593ca2ec82c20d736da03":[5,0,0,13,2],
-"classcl_1_1_image1_d_buffer.html":[5,0,0,14],
-"classcl_1_1_image1_d_buffer.html#a223b309adff248549715812239867c06":[5,0,0,14,3],
-"classcl_1_1_image1_d_buffer.html#a6b83eb1ccf0e1f88718a6f55c7340088":[5,0,0,14,2],
-"classcl_1_1_image1_d_buffer.html#ab0a784c00a7472321a630e7191d44a6a":[5,0,0,14,7],
-"classcl_1_1_image1_d_buffer.html#abdc602662150cae28b84ea24ba361277":[5,0,0,14,0],
-"classcl_1_1_image1_d_buffer.html#ac2a5ec18ce60b2a152f81a3ecca54b9a":[5,0,0,14,4],
-"classcl_1_1_image1_d_buffer.html#ad7061b0993108a3c529e8b475c234259":[5,0,0,14,5],
-"classcl_1_1_image1_d_buffer.html#af1038bf97260eb1335fe44810718209e":[5,0,0,14,6],
-"classcl_1_1_image1_d_buffer.html#af7147a48f638c9f361fa5ef586b9b18d":[5,0,0,14,1],
-"classcl_1_1_image2_d.html":[5,0,0,15],
-"classcl_1_1_image2_d.html#a01f30cbb6b4e74d81de88beb993b3d58":[5,0,0,15,5],
-"classcl_1_1_image2_d.html#a2a8221a4c64c1aaf47468c4ef6c05a61":[5,0,0,15,4],
-"classcl_1_1_image2_d.html#a368d6a9c12fd9e609a81dbe40f2d9880":[5,0,0,15,8],
-"classcl_1_1_image2_d.html#a644ebfacb26cf161eff6958db7a86a1f":[5,0,0,15,9],
-"classcl_1_1_image2_d.html#a6ef2c932d8846c4ad7205c5352df687a":[5,0,0,15,3],
-"classcl_1_1_image2_d.html#a95b1eeb977ec2f65b47617bfb541bdbd":[5,0,0,15,6],
-"classcl_1_1_image2_d.html#a994fa7059e735359e28ba9a2e389e734":[5,0,0,15,0],
-"classcl_1_1_image2_d.html#abe1d541bfe4a39bc5bae819cd5c6ef0e":[5,0,0,15,1],
-"classcl_1_1_image2_d.html#ac92eb515aa0d087cc63145ef4cfb536b":[5,0,0,15,7],
-"classcl_1_1_image2_d.html#af6e0b8578a6e36d76854468ae9dee400":[5,0,0,15,2],
-"classcl_1_1_image2_d_array.html":[5,0,0,16],
-"classcl_1_1_image2_d_array.html#a2ffded8b2fbb221d731bfe9f243bb045":[5,0,0,16,1],
-"classcl_1_1_image2_d_array.html#a4cb521f49a58328fcf7d8d31ba81f573":[5,0,0,16,3],
-"classcl_1_1_image2_d_array.html#a6e7f7e00cf4aa60ceed7e8d27d02b0f5":[5,0,0,16,7],
-"classcl_1_1_image2_d_array.html#a8c16539dc725c60ef4ff4680f8353507":[5,0,0,16,2],
-"classcl_1_1_image2_d_array.html#aad8b0d3671dd537ffa8850f50c0cfbd9":[5,0,0,16,4],
-"classcl_1_1_image2_d_array.html#aae0e2f1ba091add21d562f72bcb702d1":[5,0,0,16,5],
-"classcl_1_1_image2_d_array.html#af544260cf389184c81a62b2de5c9b96c":[5,0,0,16,6],
-"classcl_1_1_image2_d_array.html#afcc5976a23bd1c58a4639b62d2cba1ad":[5,0,0,16,0],
-"classcl_1_1_image2_d_g_l.html":[5,0,0,17],
-"classcl_1_1_image2_d_g_l.html#a0232c815761105f1c87e833a193b5bcc":[5,0,0,17,1],
-"classcl_1_1_image2_d_g_l.html#a064cb003d315b22e6c2f719054bbf7c3":[5,0,0,17,3],
-"classcl_1_1_image2_d_g_l.html#a10b2e1e124e9f1d602d83e92af665abb":[5,0,0,17,6],
-"classcl_1_1_image2_d_g_l.html#a41f087446236e9e539a451c32dc8092f":[5,0,0,17,5],
-"classcl_1_1_image2_d_g_l.html#a7a6a6d602378768878aeecafacd92911":[5,0,0,17,7],
-"classcl_1_1_image2_d_g_l.html#a7b38f17115b6098a5d8d85a4f86e6dd1":[5,0,0,17,4],
-"classcl_1_1_image2_d_g_l.html#ada8671d0fd8072472bbb36c6786506d4":[5,0,0,17,2],
-"classcl_1_1_image2_d_g_l.html#aff349860939f29111357f51fd3881917":[5,0,0,17,0],
-"classcl_1_1_image3_d.html":[5,0,0,18],
-"classcl_1_1_image3_d.html#a108db5f42ee6e0a333ee820548b1d390":[5,0,0,18,5],
-"classcl_1_1_image3_d.html#a28f004720b4cc85a902d218e3dad680d":[5,0,0,18,2],
-"classcl_1_1_image3_d.html#a498f4ca3c183f5ed8e191b8e1b7d6f6c":[5,0,0,18,7],
-"classcl_1_1_image3_d.html#a7ad39620a1c8feefc13c08df53512462":[5,0,0,18,6],
-"classcl_1_1_image3_d.html#a9243ebeec223f4c6b9681e58b8844214":[5,0,0,18,1],
-"classcl_1_1_image3_d.html#acf4e89070870a37289296e1716322c7f":[5,0,0,18,0],
-"classcl_1_1_image3_d.html#ae07b7a7f4004a6e78ece40957a6f5899":[5,0,0,18,4],
-"classcl_1_1_image3_d.html#afbb7d12774e435bc5cb33c13520a2764":[5,0,0,18,3],
-"classcl_1_1_image3_d_g_l.html":[5,0,0,19],
-"classcl_1_1_image3_d_g_l.html#a0e85acf1f34fc2bb7b5362c95afed785":[5,0,0,19,5],
-"classcl_1_1_image3_d_g_l.html#a21a8fd551430095711413e831cd42ddd":[5,0,0,19,1],
-"classcl_1_1_image3_d_g_l.html#a43fbcd25852d39c83a789699921ef7aa":[5,0,0,19,4],
-"classcl_1_1_image3_d_g_l.html#a547ae772ea5529329b278d8d551518f4":[5,0,0,19,3],
-"classcl_1_1_image3_d_g_l.html#a887ef5a5f73871e5419d9cd48cb0aae8":[5,0,0,19,0],
-"classcl_1_1_image3_d_g_l.html#a909150f0ac62ddd907bc71843916ba44":[5,0,0,19,7],
-"classcl_1_1_image3_d_g_l.html#ab06b629a6327d2931c6895d798504730":[5,0,0,19,6],
-"classcl_1_1_image3_d_g_l.html#ae4379054235116bf4e7f1107914d0ce7":[5,0,0,19,2],
 "classcl_1_1_image_g_l.html":[5,0,0,21],
 "classcl_1_1_image_g_l.html#a071bab7f0d9fd09641b139243097a157":[5,0,0,21,7],
 "classcl_1_1_image_g_l.html#a0d65fbe2960edcd3b2ba6f857d98b813":[5,0,0,21,3],
@@ -109,29 +11,31 @@ var NAVTREEINDEX1 =
 "classcl_1_1_image_g_l.html#afc06fdce130a034e8dca89ac910a93ab":[5,0,0,21,2],
 "classcl_1_1_kernel.html":[5,0,0,22],
 "classcl_1_1_kernel.html#a0869347f24520f2d59222f74297c5fe5":[5,0,0,22,4],
-"classcl_1_1_kernel.html#a09bbe9eac712ad45cda4b7363c39aa4b":[5,0,0,22,27],
+"classcl_1_1_kernel.html#a09bbe9eac712ad45cda4b7363c39aa4b":[5,0,0,22,29],
 "classcl_1_1_kernel.html#a0c71f37cb53fbe492847fbb2dff2bfed":[5,0,0,22,2],
-"classcl_1_1_kernel.html#a16d2f73d0e8e1a175bba604ae5e38b2d":[5,0,0,22,26],
+"classcl_1_1_kernel.html#a16d2f73d0e8e1a175bba604ae5e38b2d":[5,0,0,22,28],
 "classcl_1_1_kernel.html#a242f26c280c867f531cc30c953e6d4b9":[5,0,0,22,15],
-"classcl_1_1_kernel.html#a2814ec9a3596f0486b9c207c04ee0ab6":[5,0,0,22,29],
+"classcl_1_1_kernel.html#a2814ec9a3596f0486b9c207c04ee0ab6":[5,0,0,22,31],
 "classcl_1_1_kernel.html#a32b57f5ba1c9fb5d3fe1c8f5c8f067f9":[5,0,0,22,10],
 "classcl_1_1_kernel.html#a351422a7e7125812c23610628b0f9de7":[5,0,0,22,0],
-"classcl_1_1_kernel.html#a36633bcfea86c512cbb4fd9b20c6087e":[5,0,0,22,25],
+"classcl_1_1_kernel.html#a36633bcfea86c512cbb4fd9b20c6087e":[5,0,0,22,27],
 "classcl_1_1_kernel.html#a3ec081fb9656b0780d808563256dfeff":[5,0,0,22,18],
 "classcl_1_1_kernel.html#a48e36ac7c4eace006164e6b7c67c2006":[5,0,0,22,13],
-"classcl_1_1_kernel.html#a4ecc854da95b1d0c12a8072d9efb41df":[5,0,0,22,24],
+"classcl_1_1_kernel.html#a4ecc854da95b1d0c12a8072d9efb41df":[5,0,0,22,26],
+"classcl_1_1_kernel.html#a5839ea6d2e1fe0fc4068d964e1875e7e":[5,0,0,22,24],
 "classcl_1_1_kernel.html#a69b2fc97f80d90a23927a74395d09ec9":[5,0,0,22,1],
 "classcl_1_1_kernel.html#a69cdd780a6b77e3b15c7436c5ab665a3":[5,0,0,22,21],
 "classcl_1_1_kernel.html#a6b28ded6ef25514adb7450868373ee10":[5,0,0,22,11],
 "classcl_1_1_kernel.html#a73577d4ec1662b6939f8adbfff1f2d81":[5,0,0,22,16],
+"classcl_1_1_kernel.html#a85ecb20acddef088e63d91af4ca71976":[5,0,0,22,23],
 "classcl_1_1_kernel.html#a8e123d85cd5185946741057048cba828":[5,0,0,22,17],
 "classcl_1_1_kernel.html#a93b516f37993297101dd9d30a4572b23":[5,0,0,22,3],
 "classcl_1_1_kernel.html#a9516e70e10909526dfb01f6cfe8b61bd":[5,0,0,22,19],
 "classcl_1_1_kernel.html#aa389b7c8babc945491aad0969bbea3f9":[5,0,0,22,7],
 "classcl_1_1_kernel.html#aa694b5dfe7413e3a38d1185208ec1ec7":[5,0,0,22,20],
 "classcl_1_1_kernel.html#aad79793dee31368728dc5faaba31b4fe":[5,0,0,22,9],
-"classcl_1_1_kernel.html#ab2f520c71efd82ee7effff41728417dd":[5,0,0,22,28],
-"classcl_1_1_kernel.html#abadacb0037f711f3460cf5c44b2d4796":[5,0,0,22,23],
+"classcl_1_1_kernel.html#ab2f520c71efd82ee7effff41728417dd":[5,0,0,22,30],
+"classcl_1_1_kernel.html#abadacb0037f711f3460cf5c44b2d4796":[5,0,0,22,25],
 "classcl_1_1_kernel.html#ad59bdc88fe5c881ecb27d9bb212de176":[5,0,0,22,12],
 "classcl_1_1_kernel.html#ae10c336ea5a49bd7199995a6ab4c23de":[5,0,0,22,22],
 "classcl_1_1_kernel.html#ae4e8cba9366c1198454766e6b392ed1d":[5,0,0,22,14],
@@ -191,34 +95,35 @@ var NAVTREEINDEX1 =
 "classcl_1_1_program.html":[5,0,0,29],
 "classcl_1_1_program.html#a012a70fc915a06671e1d6c05ba7804df":[5,0,0,29,0],
 "classcl_1_1_program.html#a0ec5552449e9fefc46e7bcd399d15f51":[5,0,0,29,12],
-"classcl_1_1_program.html#a151e1ed12cfe99f86b8468db54fbc265":[5,0,0,29,22],
+"classcl_1_1_program.html#a151e1ed12cfe99f86b8468db54fbc265":[5,0,0,29,23],
 "classcl_1_1_program.html#a1666a02c393b46730b24a76f79302b15":[5,0,0,29,13],
 "classcl_1_1_program.html#a204c904c9fa5d0b2a65de6fc87396d30":[5,0,0,29,10],
 "classcl_1_1_program.html#a22c68c40400ddb75c0e8013629e632be":[5,0,0,29,3],
-"classcl_1_1_program.html#a262b43d736d6c1ab26619dfe8e322182":[5,0,0,29,15],
-"classcl_1_1_program.html#a2e9934036119bed18864b519ef40f47b":[5,0,0,29,24],
+"classcl_1_1_program.html#a262b43d736d6c1ab26619dfe8e322182":[5,0,0,29,16],
+"classcl_1_1_program.html#a2e9934036119bed18864b519ef40f47b":[5,0,0,29,25],
 "classcl_1_1_program.html#a367cf581b43d8ad021806a4714753437":[5,0,0,29,4],
 "classcl_1_1_program.html#a400d1a7de104d98f1d3c2aa7dccc21ba":[5,0,0,29,5],
 "classcl_1_1_program.html#a4f03f90dcd6c7b48687af389cf8b25ca":[5,0,0,29,6],
-"classcl_1_1_program.html#a5129e59abc969144a1f743c1553f8243":[5,0,0,29,19],
-"classcl_1_1_program.html#a6178a63538bdbb3b9730225a59ff465f":[5,0,0,29,20],
+"classcl_1_1_program.html#a5129e59abc969144a1f743c1553f8243":[5,0,0,29,20],
+"classcl_1_1_program.html#a6178a63538bdbb3b9730225a59ff465f":[5,0,0,29,21],
 "classcl_1_1_program.html#a7014db5c87a6c0f4877ad506dae47a8b":[5,0,0,29,14],
-"classcl_1_1_program.html#a7af446aabbe03e09180c9aad950350f9":[5,0,0,29,28],
-"classcl_1_1_program.html#a7b4512d8c730cbb4bf80e7d24f6b90b7":[5,0,0,29,29],
-"classcl_1_1_program.html#a8251f8a862bdfd82caf10a949b2bd884":[5,0,0,29,17],
-"classcl_1_1_program.html#a83a87a7d0dbbede2b28dcf8836a624b0":[5,0,0,29,18],
-"classcl_1_1_program.html#a8e6af9b0c8b2a01d4d8ad04deca61244":[5,0,0,29,16],
-"classcl_1_1_program.html#a9028e9b85aa9110a8dcc67e34f15956a":[5,0,0,29,23],
+"classcl_1_1_program.html#a760e27de80026469215445c9774bd104":[5,0,0,29,15],
+"classcl_1_1_program.html#a7b4512d8c730cbb4bf80e7d24f6b90b7":[5,0,0,29,30],
+"classcl_1_1_program.html#a8251f8a862bdfd82caf10a949b2bd884":[5,0,0,29,18],
+"classcl_1_1_program.html#a83a87a7d0dbbede2b28dcf8836a624b0":[5,0,0,29,19],
+"classcl_1_1_program.html#a8e6af9b0c8b2a01d4d8ad04deca61244":[5,0,0,29,17],
+"classcl_1_1_program.html#a9028e9b85aa9110a8dcc67e34f15956a":[5,0,0,29,24],
 "classcl_1_1_program.html#a9223820e8ac1901a84e1a1a02a97954b":[5,0,0,29,9],
-"classcl_1_1_program.html#a95095b4b07d5cb65aa8d7406ca443cf2":[5,0,0,29,21],
-"classcl_1_1_program.html#a9fefc53ce623dd7180260d83fc991ca4":[5,0,0,29,31],
+"classcl_1_1_program.html#a95095b4b07d5cb65aa8d7406ca443cf2":[5,0,0,29,22],
+"classcl_1_1_program.html#a9fefc53ce623dd7180260d83fc991ca4":[5,0,0,29,32],
 "classcl_1_1_program.html#aaac370eec783f85a00945d701d6a7e19":[5,0,0,29,11],
-"classcl_1_1_program.html#ab28c814ce62db2051041c4bf1c9b5561":[5,0,0,29,26],
-"classcl_1_1_program.html#ab2f79b4d984b3248c0486fc1e38673db":[5,0,0,29,30],
-"classcl_1_1_program.html#aca2f3a6bb7028fa2021d274cb5664725":[5,0,0,29,27],
+"classcl_1_1_program.html#ab111c1b65a2ffc86f5defbc0a3c94501":[5,0,0,29,29],
+"classcl_1_1_program.html#ab28c814ce62db2051041c4bf1c9b5561":[5,0,0,29,27],
+"classcl_1_1_program.html#ab2f79b4d984b3248c0486fc1e38673db":[5,0,0,29,31],
+"classcl_1_1_program.html#aca2f3a6bb7028fa2021d274cb5664725":[5,0,0,29,28],
 "classcl_1_1_program.html#ad260abbeb288ec0cc18d5184bf07b14a":[5,0,0,29,1],
 "classcl_1_1_program.html#af804a4cb0e2dc844c0be0b0b76dbd25a":[5,0,0,29,8],
-"classcl_1_1_program.html#afc23b6c31e74af370da1b5766a7a0c7b":[5,0,0,29,25],
+"classcl_1_1_program.html#afc23b6c31e74af370da1b5766a7a0c7b":[5,0,0,29,26],
 "classcl_1_1_program.html#afc8d71b6035a8084636c9b9f3ed568b2":[5,0,0,29,2],
 "classcl_1_1_program.html#afeec80b90b56f6407b138b9e8f10e8bc":[5,0,0,29,7],
 "classcl_1_1_s_v_m_allocator.html":[5,0,0,31],
@@ -249,5 +154,100 @@ var NAVTREEINDEX1 =
 "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html#a356abe3291495edb036a25d781906a5a":[5,0,0,32,2],
 "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html#aaecf5bd2072db1c4df4c51aaf5098a4f":[5,0,0,32,3],
 "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html#ad09aa943957ab0ab739d72279081d0b7":[5,0,0,32,1],
-"classcl_1_1_s_v_m_trait_atomic.html":[5,0,0,33]
+"classcl_1_1_s_v_m_trait_atomic.html":[5,0,0,33],
+"classcl_1_1_s_v_m_trait_coarse.html":[5,0,0,34],
+"classcl_1_1_s_v_m_trait_fine.html":[5,0,0,35],
+"classcl_1_1_s_v_m_trait_read_only.html":[5,0,0,36],
+"classcl_1_1_s_v_m_trait_read_write.html":[5,0,0,37],
+"classcl_1_1_s_v_m_trait_write_only.html":[5,0,0,38],
+"classcl_1_1_sampler.html":[5,0,0,30],
+"classcl_1_1_sampler.html#a011eed498881010b78ffdcdd9fcb4056":[5,0,0,30,7],
+"classcl_1_1_sampler.html#a1c8395b386e3b1c09dc43f4134909390":[5,0,0,30,0],
+"classcl_1_1_sampler.html#a41d7df0a069717bc570a6ccdab3d3acd":[5,0,0,30,1],
+"classcl_1_1_sampler.html#a487aa40df9ababf70fe4c19a0b538f6f":[5,0,0,30,4],
+"classcl_1_1_sampler.html#a684ea0f7bb85233239ba3a266795c1a4":[5,0,0,30,3],
+"classcl_1_1_sampler.html#a692268678bf12b7b754009f9ba291fbc":[5,0,0,30,6],
+"classcl_1_1_sampler.html#a8d58fcb1dc466f4b1de2c38c6cb76823":[5,0,0,30,9],
+"classcl_1_1_sampler.html#aa32c71d59ca20e83fc283273d0b102cd":[5,0,0,30,2],
+"classcl_1_1_sampler.html#ad26196f0282429667828b5b39bbc97f1":[5,0,0,30,8],
+"classcl_1_1_sampler.html#afc12ea7675deef235c907034f72a0476":[5,0,0,30,5],
+"classcl_1_1_user_event.html":[5,0,0,39],
+"classcl_1_1_user_event.html#a1ee5bc016d511a4fec5f23b50a70821a":[5,0,0,39,1],
+"classcl_1_1_user_event.html#a4255beef279789245d402a00830c841f":[5,0,0,39,0],
+"classcl_1_1_user_event.html#ad1df3a34596fee2bf6f1de6893192ae5":[5,0,0,39,2],
+"classcl_1_1detail_1_1_deleter.html":[5,0,0,1,0],
+"classcl_1_1detail_1_1_deleter.html#a119b0a92bdab899d0dbfe1840ec1d1d0":[5,0,0,1,0,2],
+"classcl_1_1detail_1_1_deleter.html#a899859732bb1c5f296f3e4f05ca6a39d":[5,0,0,1,0,1],
+"classcl_1_1detail_1_1_deleter.html#a96396087a885bd82e574d133e6583682":[5,0,0,1,0,0],
+"classcl_1_1detail_1_1_s_v_m_trait_null.html":[5,0,0,1,19],
+"classcl_1_1detail_1_1_wrapper.html":[5,0,0,1,20],
+"classcl_1_1detail_1_1_wrapper.html#a044bc05bb3eb90345cb9cf574b95a98f":[5,0,0,1,20,10],
+"classcl_1_1detail_1_1_wrapper.html#a115618e2baf10ec5c09513394d985ea6":[5,0,0,1,20,5],
+"classcl_1_1detail_1_1_wrapper.html#a1292547dd0c591aa972e25b793481583":[5,0,0,1,20,15],
+"classcl_1_1detail_1_1_wrapper.html#a17726beb74f709c3ed5ac06ac2737c3e":[5,0,0,1,20,14],
+"classcl_1_1detail_1_1_wrapper.html#a207374e201c6c33c01bdc7ee09e92d76":[5,0,0,1,20,12],
+"classcl_1_1detail_1_1_wrapper.html#a2d10265f9935f18fed55abe2560cd199":[5,0,0,1,20,11],
+"classcl_1_1detail_1_1_wrapper.html#a47164ab536bdd1bdc4b9766354b5a982":[5,0,0,1,20,9],
+"classcl_1_1detail_1_1_wrapper.html#a5aa32c6d3304d4ee9fb63491a72b0d58":[5,0,0,1,20,7],
+"classcl_1_1detail_1_1_wrapper.html#a83841267bac5ad4411ec8935f78315d8":[5,0,0,1,20,0],
+"classcl_1_1detail_1_1_wrapper.html#a89adf70432169d0b0a82bc6696a9aad1":[5,0,0,1,20,8],
+"classcl_1_1detail_1_1_wrapper.html#a98dce667e0f400f2ba15a8a8d65fdea0":[5,0,0,1,20,2],
+"classcl_1_1detail_1_1_wrapper.html#aa1b916a75114fe3217018378d5f1eb71":[5,0,0,1,20,1],
+"classcl_1_1detail_1_1_wrapper.html#aa254b6401dc19abcc7c21d2a664cadf9":[5,0,0,1,20,3],
+"classcl_1_1detail_1_1_wrapper.html#adc64140f053332174a28ea24db94842c":[5,0,0,1,20,6],
+"classcl_1_1detail_1_1_wrapper.html#adfdff8a6c98ca62fedc6a9ffced47a06":[5,0,0,1,20,13],
+"classcl_1_1detail_1_1_wrapper.html#af91bafdf8593c34e0d0722cdd93010be":[5,0,0,1,20,4],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html":[5,0,0,1,21],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a0861309296077e75b77d39e2cfeada11":[5,0,0,1,21,7],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a0abf5113a5123b8de94685ddfa214bd0":[5,0,0,1,21,4],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a17726beb74f709c3ed5ac06ac2737c3e":[5,0,0,1,21,14],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a272411e6c7274702cfe640a52566cf67":[5,0,0,1,21,10],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a2c117e3bbe52e50aa462f8da53278484":[5,0,0,1,21,0],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a34bae3d4d284c0ea2921182962c210df":[5,0,0,1,21,16],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a43175aa1ebaacc04c9394b69ef2bcb45":[5,0,0,1,21,8],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a5ec1f410d9e0564c990300308be2fa76":[5,0,0,1,21,12],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a653647657df23934f684f332cf2c545e":[5,0,0,1,21,9],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6881f47b159f53e2efefc3325127bdc5":[5,0,0,1,21,1],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a69a1b6a912ec468216ddfec1f5b6598e":[5,0,0,1,21,2],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6a4506b8f3920fb2487b1a5448a6f10c":[5,0,0,1,21,5],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6b9c9bb8cab1ef5e8c684d6c382b4522":[5,0,0,1,21,13],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6bf49a144579823e03d4e88cafc4fb9d":[5,0,0,1,21,17],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a973484a071d325cce40155782841dcfe":[5,0,0,1,21,15],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#aba1abbf064a0b6e4d3c44c2e3ac68564":[5,0,0,1,21,6],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#ad0be1f0116796955d20d592e5ed8f34c":[5,0,0,1,21,11],
+"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#adc34e0d2c80d7994fd7077902e8ceb68":[5,0,0,1,21,3],
+"classes.html":[5,1],
+"files.html":[6,0],
+"functions.html":[5,3,0,0],
+"functions.html":[5,3,0],
+"functions_b.html":[5,3,0,1],
+"functions_c.html":[5,3,0,2],
+"functions_d.html":[5,3,0,3],
+"functions_e.html":[5,3,0,4],
+"functions_func.html":[5,3,1],
+"functions_func.html":[5,3,1,0],
+"functions_func_b.html":[5,3,1,1],
+"functions_func_c.html":[5,3,1,2],
+"functions_func_d.html":[5,3,1,3],
+"functions_func_e.html":[5,3,1,4],
+"functions_func_g.html":[5,3,1,5],
+"functions_func_i.html":[5,3,1,6],
+"functions_func_k.html":[5,3,1,7],
+"functions_func_m.html":[5,3,1,8],
+"functions_func_n.html":[5,3,1,9],
+"functions_func_o.html":[5,3,1,10],
+"functions_func_p.html":[5,3,1,11],
+"functions_func_r.html":[5,3,1,12],
+"functions_func_s.html":[5,3,1,13],
+"functions_func_u.html":[5,3,1,14],
+"functions_func_w.html":[5,3,1,15],
+"functions_g.html":[5,3,0,5],
+"functions_i.html":[5,3,0,6],
+"functions_k.html":[5,3,0,7],
+"functions_m.html":[5,3,0,8],
+"functions_n.html":[5,3,0,9],
+"functions_o.html":[5,3,0,10],
+"functions_p.html":[5,3,0,11],
+"functions_r.html":[5,3,0,12],
+"functions_s.html":[5,3,0,13]
 };
